pub struct CellLocation {
pub x: u16,
pub y: u16,
}Expand description
An (x, y) index of a specific cell on the terminal (i.e. specific location where a single character could be printed)
Fields
x: u16The x-index
y: u16The y-index