pub enum TransmitError<InputError: Error> {
Writing(Error),
ReadingInput(InputError),
ParsingResponse(ParseError),
Terminal(TerminalError),
}Expand description
An error that can arise when transmitting an image to the terminal. This sort of error can also occur when just sending an image to query about it.
Variants
Writing(Error)
The writer returned an error when we tried to write to it
ReadingInput(InputError)
An error occurred when we tried to read a response from the terminal after transmitting the image
ParsingResponse(ParseError)
We got a response from the terminal, but the data it contained didn’t match the format we expected and we don’t know exactly what to do with it.
Terminal(TerminalError)
We got a response from the terminal and parsed it correctly. It contained an error, such as that we sent nonsense data or it can’t find the file specified or something